/* ------------------------------------------------------------------------------
    I N T K - T H E M E
--------------------------------------------------------------------------------- */

/* FONTS */

@font-face {
  font-family: 'BrandonText-Regular';
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Regular.otf') format('opentype');
}

@font-face {
  font-family: 'BrandonText-Bold';
  font-weight: bold;
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Bold.otf') format('opentype');
}

@font-face {
  font-family: 'BrandonText-Medium';
  font-weight: bold;
  src: url('++resource++plonetheme.bootstrapModern.fonts/BrandonText-Medium.otf') format('opentype');
}

.no-space {
    margin-left: 0px !important;
}

/* BODY */
body {
  background-color: #f8f8f8;
}

#parent-fieldname-title {
    font-size:24px;
    text-transform: uppercase;
    color: #242424;
    font-family: "BrandonText-Bold";
}

#content .documentDescription {
    font-size: 18px;
    color: #999999;
    font: 18px "BrandonText-Regular", Arial, FreeSans, sans-serif;
}

#content-core {
    margin-top: 25px;
}

.container-fluid {
    padding-left: 25px;
    padding-right: 25px;
}

/* Override media queries */

@media (min-width: 568px) {
    #portal-columns {
        padding-left: 25px !important;
        padding-right: 25px !important;
    }

    #content .container-fluid {
        padding-left: 0px !important; /* 25px - 20px */
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: left;
    }
}

@media (max-width: 767px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
    .container-fluid {
        padding-left: 25px;
        padding-right:25px;
    }

    #content .container-fluid {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }
}

@media (min-width: 992px) {
    #portal-columns {
        padding-left: 40px !important;
        padding-right: 40px !important;
    }

    #content .container-fluid {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: left;
    }
}

@media (min-width: 1200px) {
    #portal-columns {
        padding-left: 120px !important;
        padding-right: 120px !important;
    }

    #content .container-fluid {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: center;
    }
}


/* COLLECTION */

#content-core .thumb-image img {
    width: 100%;
    display: block;
    margin: 0 auto;
}

#content-core .thumbnail {
    background-color: #f8f8f8;
    border: none;
    box-shadow: none;
    -webkit-box-shadow: none;
    margin-bottom: 45px;
    padding: 0px;
}

#content-core .caption {
    padding: 0px;
}

#content-core .thumbnail h3 {
    margin-top: 12px; /* margin from title to image */
    margin-bottom: 4px;
    text-transform: none;
    font-family: "BrandonText-Medium";
    font-color: #242424;
    font-size: 18px;
    line-height: 26px;
}

#content-core .thumbnail a {
    text-decoration: none;
    color: #666666;
    font-size: 18px;
    border-bottom: none;
}

#content-core .thumbnail p {
    font-size: 18px;
    font-family: "BrandonText-Regular";
    color: #999999;
    line-height: 26px;
}
